@@ -491,7 +491,7 @@ class ITinyMCELayoutSchema(Interface):
             "Enter a JSON-formatted style format configuration. "
             "A format is for example the style that get applied when "
             "you press the bold button inside the editor. "
-            "See https://www.tinymce.com/docs/configure/content-formatting/#formats"
+            "See https://www.tiny.cloud/docs/tinymce/latest/content-formatting/"
         ),
         constraint=validate_json,
         default=dump_json_to_text(
@@ -695,79 +695,6 @@ class ITinyMCEPluginSchema(Interface):
 ITinyMCELibrariesSchema = ITinyMCEPluginSchema  # bw compat
 
 
-class ITinyMCESpellCheckerSchema(Interface):
-    """This interface defines the libraries properties."""
-
-    libraries_spellchecker_choice = schema.Choice(
-        title=_("Spellchecker plugin to use"),
-        description=_("This option allows you to choose the spellchecker for TinyMCE."),
-        missing_value=set(),
-        vocabulary=SimpleVocabulary(
-            [
-                SimpleTerm("browser", "browser", _("Default browser spellchecker")),
-                SimpleTerm("AtD", "AtD", _("After the deadline (FLOSS)")),
-            ]
-        ),
-        default="browser",
-        required=False,
-    )
-
-    libraries_atd_ignore_strings = schema.List(
-        title=_("AtD ignore strings"),
-        description=_(
-            "label_atd_ignore_strings",
-            default='A list of strings which the "After the Deadline" '
-            "spellchecker should ignore. "
-            "Note: This option is only applicable when the "
-            "appropriate spellchecker has been chosen above.",
-        ),
-        default=["Zope", "Plone", "TinyMCE"],
-        value_type=schema.TextLine(),
-        missing_value=[],
-        required=False,
-    )
-
-    libraries_atd_show_types = schema.List(
-        title=_("AtD error types to show"),
-        description=_(
-            "help_atderrortypes_to_show",
-            default="A list of error types which the "
-            '"After the Deadline" spellchecker should check for. '
-            "By default, all the available error type will be "
-            "listed here.",
-        ),
-        value_type=schema.TextLine(),
-        default=[
-            "Bias Language",
-            "Cliches",
-            "Complex Expression",
-            "Diacritical Marks",
-            "Double Negatives",
-            "Hidden Verbs",
-            "Jargon Language",
-            "Passive voice",
-            "Phrases to Avoid",
-            "Redundant Expression",
-        ],
-        missing_value=[],
-        required=False,
-    )
-
-    libraries_atd_service_url = schema.TextLine(
-        title=_("AtD service URL"),
-        description=_(
-            "help_atd_service_url",
-            default='The URL of the "After the Deadline" grammar and spell '
-            "checking server. "
-            "The default value is the public server, "
-            "but ideally you should download and install your own "
-            "and specify its address here.",
-        ),
-        required=True,
-        default="service.afterthedeadline.com",
-    )
-
-
 class ITinyMCEResourceTypesSchema(Interface):
     """This interface defines the resource types properties."""
 
@@ -845,7 +772,6 @@ class ITinyMCEAdvancedSchema(Interface):
 class ITinyMCESchema(
     ITinyMCELayoutSchema,
     ITinyMCEPluginSchema,
-    ITinyMCESpellCheckerSchema,
     ITinyMCEResourceTypesSchema,
     ITinyMCEAdvancedSchema,
 ):
